@@ -125,7 +125,8 @@ class CustomFormatter(logging.Formatter):
     3. Shortens 'funcName' and 'filename' so to not cause issues with the formatting.
     """
 
-    def __init__(self, fmt: Optional[str] = None, datefmt: Optional[str] = None, style='%', validate: bool = True, error_formatter: Callable = None, no_newline_on_error: bool = False) -> None:
+    def __init__(self, fmt: Optional[str] = None, max_name_size: int = 25, datefmt: Optional[str] = None, style='%', validate: bool = True, error_formatter: Callable = None, no_newline_on_error: bool = False) -> None:
+        self.max_name_size = max_name_size
         super().__init__(fmt=fmt, datefmt=datefmt, style=style, validate=validate)
         self.error_formatter = error_formatter
         self.no_newline_on_error = no_newline_on_error
@@ -141,8 +142,8 @@ class CustomFormatter(logging.Formatter):
             record.levelname = record.levelname[:11 - 3] + '...'
         if len(record.threadName) >= 12:
             record.threadName = record.threadName[-(12 - 3):] + '...'
-        if len(record.name) >= 50:
-            record.name = '...' + record.name[-(50 - 3):]
+        if len(record.name) >= self.max_name_size:
+            record.name = '...' + record.name[-(self.max_name_size - 3):]
         if len(record.funcName) >= 30:
             record.funcName = record.funcName[:30 - 3] + '...'
 
@@ -167,7 +168,7 @@ class ExcludeProfilingStreamHandler(logging.StreamHandler):
 
 
 def marked_exception_formatter(in_text: str) -> str:
-    text = f"| EXCEPTION START |\n\n{in_text}\n\n| EXCEPTION END |"
+    text = f"<TRACEBACK>\n\n{in_text}\n\n</TRACEBACK>"
     return text
 
 
